@@ -67,7 +67,6 @@ from apischema.utils import (
     Lazy,
     as_predicate,
     context_setter,
-    deprecate_kwargs,
     empty_dict,
     get_args2,
     get_origin2,
@@ -150,11 +149,10 @@ def get_deprecated(
     if not schema_dict.get("deprecated", False):
         return None
     while schema is not None:
-        if schema.annotations is not None:
-            if isinstance(schema.annotations.deprecated, str):
-                return schema.annotations.deprecated
-            elif schema.annotations.deprecated:
-                return graphql.DEFAULT_DEPRECATION_REASON
+        if isinstance(schema.deprecated, str):
+            return schema.deprecated
+        elif schema.deprecated:
+            return graphql.DEFAULT_DEPRECATION_REASON
         schema = schema.child
     return graphql.DEFAULT_DEPRECATION_REASON
 
@@ -198,7 +196,7 @@ class TypeFactory(Generic[GraphQLTp]):
 
     @property
     def type(self) -> GraphQLTp:
-        return self.factory(self.name, self.description)  # type: ignore
+        return self.factory(self.name, self.description)
 
     @property
     def raw_type(self) -> GraphQLTp:
@@ -220,12 +218,12 @@ def cache_type(method: Method) -> Method:
     def wrapper(self: "SchemaBuilder", *args, **kwargs):
         factory = method(self, *args, **kwargs)
 
-        @wraps(factory.factory)  # type: ignore
+        @wraps(factory.factory)
         def name_cache(
             name: Optional[str], description: Optional[str]
         ) -> graphql.GraphQLNonNull:
             if name is None:
-                tp = factory.factory(name, description)  # type: ignore
+                tp = factory.factory(name, description)
                 return graphql.GraphQLNonNull(tp) if tp is not JSON_SCALAR else tp
             # Method is in cache key because scalar types will have the same method,
             # and then be shared by both visitors, while input/output types will have
@@ -234,7 +232,7 @@ def cache_type(method: Method) -> Method:
                 tp, cached_args = self._cache_by_name[(name, method, description)]
                 if cached_args == (args, kwargs):
                     return tp
-            tp = graphql.GraphQLNonNull(factory.factory(name, description))  # type: ignore
+            tp = graphql.GraphQLNonNull(factory.factory(name, description))
             # Don't put args in cache in order to avoid hashable issue
             self._cache_by_name[(name, method, description)] = (tp, (args, kwargs))
             return tp
@@ -275,7 +273,7 @@ class SchemaBuilder(
     ) -> TypeFactory[GraphQLTp]:
         def factory(name: Optional[str], description: Optional[str]) -> GraphQLTp:
             cached_fact = lazy()
-            return cached_fact.factory(  # type: ignore
+            return cached_fact.factory(
                 name or cached_fact.name, description or cached_fact.description
             )
 
@@ -397,7 +395,7 @@ class SchemaBuilder(
         if NoneType in types or UndefinedType in types:
 
             def nullable(name: Optional[str], description: Optional[str]) -> GraphQLTp:
-                res = factory.factory(name, description)  # type: ignore
+                res = factory.factory(name, description)
                 return res.of_type if isinstance(res, graphql.GraphQLNonNull) else res
 
             return replace(factory, factory=nullable)
@@ -861,11 +859,13 @@ def operation_resolver(operation: Union[Callable, Op], op_class: Type[Op]) -> Re
     op = operation.function
     if iscoroutinefunction(op):
 
+        @wraps(op)
         async def wrapper(_, *args, **kwargs):
             return await op(*args, **kwargs)
 
     else:
 
+        @wraps(op)
         def wrapper(_, *args, **kwargs):
             return op(*args, **kwargs)
 
@@ -884,7 +884,6 @@ def operation_resolver(operation: Union[Callable, Op], op_class: Type[Op]) -> Re
     )
 
 
-@deprecate_kwargs({"union_ref": "union_name"})
 def graphql_schema(
     *,
     query: Iterable[Union[Callable, Query]] = (),
@@ -931,7 +930,7 @@ def graphql_schema(
             fields.append(resolver_field)
     for sub_op in subscription:
         if not isinstance(sub_op, Subscription):
-            sub_op = Subscription(sub_op)  # type: ignore
+            sub_op = Subscription(sub_op)
         sub_parameters: Sequence[Parameter]
         if sub_op.resolver is not None:
             subscriber2 = operation_resolver(sub_op, Subscription)
